<?php

    class WPPeelAndReveal {
        var $option_names = array(
            'settings' => "wp_peel_and_reveal_settings",
            'statistics' => "wp_peel_and_reveal_statictics"
        );
        
        var $options = array(
            'settings' => array(
                'linkurl' => "http://multiplestreamsthemes.com/",
                'new_window' => '1',
                'use_template' => '0',
                'template' => 'advertise'
            ),
            'statistics' => array(
                'views' => 0,
                'clicks' => 0
            )
        );
        
        function saveOption($option_set) {
            return update_option($this->option_names[$option_set], $this->options[$option_set]);
        }
        
        function loadOption($option_set) {
            $option = get_option($this->option_names[$option_set]);
            if (false == $option) {
                $this->saveOption($option_set);
            } else {
                $this->options[$option_set] = array_merge($this->options[$option_set], $option);                
            }
        }
        
        function __construct() {
            $this->loadOption('settings');                             
                
            if (is_admin()) {
                $this->loadOption('statistics');
                add_action('admin_init', array($this, 'registerSettings')); 
                add_action('admin_menu', array($this, 'adminMenuHandler'));   
                
                // To be enqueued on specific page.
                wp_enqueue_script("pg-cpa-admin", PA_PLUGIN_URL."/script/pg-cpa-admin.js", array("jquery")); 
            } else {                          
                add_action('init', array($this, 'initHandler'));                                                     
            }                                                                   
            
            // Problem with adding to user context.
            add_action('wp_ajax_nopriv_pg_pa_counter', array($this, 'ajaxCounterHandler'));
            add_action('wp_ajax_pg_pa_counter', array($this, 'ajaxCounterHandler'));  
        }
        
        function initHandler() {
            wp_enqueue_script('jquery.pngfix', PA_PLUGIN_URL.'/script/jquery.pngfix.js', array('jquery'));   
            wp_enqueue_script('pg-cpa', PA_PLUGIN_URL.'/script/pg-cpa.js', array('jquery'));   
            wp_localize_script('pg-cpa', 'pg_cpa', array(
                'au' => admin_url('admin-ajax.php'), 
                'l' => $this->options['settings']['linkurl'],
                'i' => PA_PLUGIN_URL.'/image/curl.png',
                'i_ie' => PA_PLUGIN_URL.'/image/curl.png',
                'nw' => $this->options['settings']['new_window'],
                'r' => 744/640, //autopeelRatio 
                'ot' =>  800, //autopeelOpenTime
                'ct' =>  1200, //autopeelCloseTime
                'bw' =>  74, // 75, Before Width
                'bh' =>  77, // 75, Before Height
                'aw' =>  500, // 328, After Width
                'ah' =>  500 // 328, After Height
            )); 
            
            
            wp_enqueue_style('pg-cpa', PA_PLUGIN_URL.'/style/pg-cpa.css');
            if (1 == $this->options['settings']['use_template']) {
                wp_enqueue_style('pg-cpa-template', PA_PLUGIN_URL."/template/{$this->options['settings']['template']}/pg-cpa.css");
            }
        }
        
        function ajaxCounterHandler() {
            switch (strtolower($_POST['s'])) {
                case 'click':
                    $this->options['statistics']['clicks'] += 1;
                    $this->saveOption('statistics');
                break;
                
                case 'view':
                    $this->options['statistics']['views'] += 1;
                    $this->saveOption('statistics');
                break;
            }                 
                              
            die();
        }
        
        function adminMenuHandler() {
            add_menu_page(__('Settings'), __('WP Peel &amp; Reveal'), 'manage_options', 'pg-cpa-handle', array($this, 'settingsPage'));
            add_submenu_page('pg-cpa-handle', __('Settings'), __('Settings'), 'manage_options', 'pg-cpa-handle', array($this, 'settingsPage'));
            add_submenu_page('pg-cpa-handle', 'Statistics', 'Statistics', 'manage_options', 'pg-cpa-statistics-handle', array($this, 'statisticsPage'));
        }
        
        function registerSettings() {                       
            register_setting($this->option_names['settings'], $this->option_names['settings'], array($this, "settingsValidationHandler"));     
        }
        
        function settingsPage() {
            $templates = cpa_list_dirs(PA_PLUGIN_DIR."/template/");      
            
            cpa_load_view('settings', array('cpa' => $this, 'templates' => $templates));
        }
        
        function settingsValidationHandler($input) {
            if($_FILES['before']['size'] > 0) {
                $tmp_name = $_FILES['before']['tmp_name'];
                move_uploaded_file($tmp_name, PA_PLUGIN_DIR."/image/before.jpg");
            }

            if($_FILES['after']['size'] > 0) {
                $tmp_name = $_FILES['after']['tmp_name'];
                move_uploaded_file($tmp_name, PA_PLUGIN_DIR."/image/after.jpg");
            } 
            
            $input['linkurl'] = trim($input['linkurl']);
            
            return $input;
        }
        
        function statisticsPage() {
            cpa_load_view('statistics', array('s' => $this->options['statistics']));
        }     
    }  
    
?>